using System;
using System.Text.Json.Serialization;
namespace org.accordproject.cicero.dom {
   using org.accordproject.cicero.contract;
   using concerto;
   class Metadata : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Metadata";
      public string version { get; set; }
      public string locale { get; set; }
   }
   abstract class Element : Asset {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Element";
      public string id { get; set; }
   }
   class ContractTemplate : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.ContractTemplate";
      public Metadata metadata { get; set; }
      public Section content { get; set; }
   }
   class ClauseTemplate : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.ClauseTemplate";
      public Metadata metadata { get; set; }
      public Section content { get; set; }
   }
   class Text : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Text";
      public string content { get; set; }
      public string locale { get; set; }
   }
   class Parameter : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Parameter";
      public string name { get; set; }
      public string description { get; set; }
      public string type { get; set; }
      public BooleanExpression constraint { get; set; }
   }
   class Choice : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Choice";
      public Element[] options { get; set; }
      public bool required { get; set; }
   }
   class Conditional : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Conditional";
      public Element element { get; set; }
      public BooleanExpression predicate { get; set; }
   }
   abstract class Clause : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Clause";
      public string templateUri { get; set; }
   }
   class SigningParty : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.SigningParty";
      public Text description { get; set; }
      public AccordParty party { get; set; }
   }
   class Signatures : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Signatures";
      public SigningParty[] parties { get; set; }
   }
   class Link : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Link";
      public Element reference { get; set; }
   }
   class Section : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Section";
      public Text heading { get; set; }
      public Element[] children { get; set; }
      public bool pageBreak { get; set; }
   }
   enum ListStyle {
      ORDERED,
      UNORDERED,
      SINGLE_LINE,
   }

   class List : Section {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.List";
      public ListStyle style { get; set; }
      public string separator { get; set; }
   }
   abstract class Script : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Script";
      public string language { get; set; }
      public string version { get; set; }
      public string code { get; set; }
   }
   class Declarations : Script {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Declarations";
   }
   abstract class Expression : Script {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.Expression";
   }
   class ElementExpression : Expression {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.ElementExpression";
   }
   class BooleanExpression : Expression {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.cicero.dom.BooleanExpression";
   }
}
